<!-- index.rst content start -->

# Chips (all that and a bag of)

The `chips` package is a simple package for various python scripts. The ultimate
testing ground, caveat lector.

## Installation

To install the package, run:

```bash
pip install bagofchips
```
